﻿using System;
using System.Runtime.Serialization;
using System.Security.Permissions;
using System.Text;

namespace Grinder.Settings
{
    [Serializable]
    public sealed class InvalidIniEntryException : Exception
    {
        private readonly string _line;

        public string Line { get { return _line; } }

        public override string Message
        {
            get
            {
                if (string.IsNullOrEmpty(_line)) return base.Message;
                var msg = new StringBuilder(base.Message);
                msg.Append(_line);
                return msg.ToString();
            }
        }

        public InvalidIniEntryException() { }
        public InvalidIniEntryException(string message) : base(message) { }
        public InvalidIniEntryException(string message, Exception innerException) : base(message, innerException) { }

        public InvalidIniEntryException(string message, string line) :
            this(message) { _line = line; }

        public InvalidIniEntryException(string message, string line, Exception innerException) :
            this(message, innerException) { _line = line; }

        private InvalidIniEntryException(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
            _line = info.GetString("Line");
        }

        [SecurityPermission(SecurityAction.Demand, SerializationFormatter = true)]
        public override void GetObjectData(SerializationInfo info, StreamingContext context)
        {
            base.GetObjectData(info, context);
            info.AddValue("Line", _line);
        }
    }
}
